@@ -50,19 +50,15 @@ def read_parameters(input_file):
     system = str(lista[10])
     
     DT = float(lista[11])
-    tau = int(lista[12])
-    
-    T = float(lista[13])
-    
-    windowing = int(lista[14])
-    
+
+            
 #    brchs = lista[14]
 #    branches = np.fromstring(brchs, dtype=np.int, sep=',')
 #    
 #    max_Z = float(lista[15])
     
     f.close()
-    return lattice_param, Masses, n_atom_unit_cell, n_atom_conventional_cell, N1,N2,N3, ks, file_eigenvectors, file_trajectory, file_initial_conf, system, DT, tau, T, windowing
+    return lattice_param, Masses, n_atom_unit_cell, n_atom_conventional_cell, N1,N2,N3, ks, file_eigenvectors, file_trajectory, file_initial_conf, system, DT
 
 
 
@@ -75,8 +71,8 @@ def read_post_proc(input_file):
     for string in A:
         index = string.find('=')+2
         lista.append(string[index:-1])
-        
-    mode = int(lista[1])
+    
+    plot_types = np.fromstring(lista[1], dtype=np.int, sep=',')
     
     ns = lista[2]
     n_atom_unit_cell = np.fromstring(ns, dtype=np.int, sep=',')
@@ -97,7 +93,7 @@ def read_post_proc(input_file):
     
     temperature_folders = lista[8]
     
-    return mode, n_atom_unit_cell, file_eigenvectors, max_Z, kpoints, labels, modes, temperature_folders
+    return plot_types, n_atom_unit_cell, file_eigenvectors, max_Z, kpoints, labels, modes, temperature_folders
 
 
 
